@@ -1,16 +1,16 @@
 package Mylisp::Grammar;
 
 use 5.012;
-no warnings "experimental";
+no warnings 'experimental';
 
 use Exporter;
 our @ISA    = qw(Exporter);
-our @EXPORT = qw(get_mylisp_grammar);
+our @EXPORT = qw(get_my_grammar);
 
-sub get_mylisp_grammar {
+sub get_my_grammar {
   return <<'EOF'
 
-   mylisp = ^ |_ _pod Expr|+ $ ;
+   door   = ^ |_ _pod Expr|+ $ ;
 
    _      = |\s+ _comm|+ ;
    _pod   = '=pod' ~ '=end' ;
